==> blsdk_plugin-0.0.4.tar.gz: ios/Classes/BlsdkPlugin.m <==
#import "BlsdkPlugin.h"
#import "BLAppSDKManager.h"

@implementation BlsdkPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"blsdk_plugin"
            binaryMessenger:[registrar messenger]];
  BlsdkPlugin* instance = [[BlsdkPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"getPlatformVersion" isEqualToString:call.method]) {
    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  }else if ([@"init_blsdk" isEqualToString:call.method]) {
     BOOL isSuccess = [[BLAppSDKManager sharedManager] blAppSDKInitWithInfo:[[BLAppSDKManager sharedManager] p_toDictory:[call.arguments objectForKey:@"data"]]];
      result(@(isSuccess));
  }else if ([@"start_probe" isEqualToString:call.method]) {
      [[BLAppSDKManager sharedManager] startPorb];
      result(@"");
  }else if ([@"stop_probe" isEqualToString:call.method]) {
      [[BLAppSDKManager sharedManager] stopProb];
      result(@"");
  }else if ([@"get_probed_device_cache" isEqualToString:call.method]) {
     NSArray *arr = [[BLAppSDKManager sharedManager] getProbedDeviceCache];
      NSString *resultStr = [arr componentsJoinedByString:@","];
      result(resultStr);
  }else if ([@"control_command" isEqualToString:call.method]) {
      [[BLAppSDKManager sharedManager] controlDeviceWithInfo:[[BLAppSDKManager sharedManager] p_toDictory:[call.arguments objectForKey:@"data"]] success:^(id  _Nullable param) {
          result([[BLAppSDKManager sharedManager] p_toJsonString:param]);
      } failure:^(id  _Nonnull param) {
          result([[BLAppSDKManager sharedManager] p_toJsonString:param]);
      }];
  }else if ([@"query_command" isEqualToString:call.method]) {
      [[BLAppSDKManager sharedManager] getDeviceStatusWithInfo:[[BLAppSDKManager sharedManager] p_toDictory:[call.arguments objectForKey:@"data"]] success:^(id  _Nullable param) {
          result([[BLAppSDKManager sharedManager] p_toJsonString:param]);
      } failure:^(id  _Nonnull param) {
          result([[BLAppSDKManager sharedManager] p_toJsonString:param]);
      }];
  }  else {
    result(FlutterMethodNotImplemented);
  }
}

@end

==> blsdk_plugin-0.0.6.tar.gz: ios/Classes/BlsdkPlugin.m <==
#import "BlsdkPlugin.h"
#import "BLAppSDKManager.h"

@implementation BlsdkPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"blsdk_plugin"
            binaryMessenger:[registrar messenger]];
  BlsdkPlugin* instance = [[BlsdkPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"getPlatformVersion" isEqualToString:call.method]) {
    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  }else if ([@"init_blsdk" isEqualToString:call.method]) {
     BOOL isSuccess = [[BLAppSDKManager sharedManager] blAppSDKInitWithInfo:[[BLAppSDKManager sharedManager] p_toDictory:[call.arguments objectForKey:@"data"]]];
      result(@(isSuccess));
  }else if ([@"start_probe" isEqualToString:call.method]) {
      [[BLAppSDKManager sharedManager] startPorbWithTime:[[call.arguments objectForKey:@"probe_interval"] integerValue]];
      result(@"");
  }else if ([@"stop_probe" isEqualToString:call.method]) {
      [[BLAppSDKManager sharedManager] stopProb];
      result(@"");
  }else if ([@"get_probed_device_cache" isEqualToString:call.method]) {
      NSString *resultStr = [[BLAppSDKManager sharedManager] getProbedDeviceCache];
      result(resultStr);
  }else if ([@"control_command" isEqualToString:call.method]) {
      [[BLAppSDKManager sharedManager] controlDeviceWithInfo:[[BLAppSDKManager sharedManager] p_toDictory:[call.arguments objectForKey:@"data"]] success:^(id  _Nullable param) {
          result([[BLAppSDKManager sharedManager] p_toJsonString:param]);
      } failure:^(id  _Nonnull param) {
          result([[BLAppSDKManager sharedManager] p_toJsonString:param]);
      }];
  }else if ([@"query_command" isEqualToString:call.method]) {
      [[BLAppSDKManager sharedManager] getDeviceStatusWithInfo:[[BLAppSDKManager sharedManager] p_toDictory:[call.arguments objectForKey:@"data"]] success:^(id  _Nullable param) {
          result([[BLAppSDKManager sharedManager] p_toJsonString:param]);
      } failure:^(id  _Nonnull param) {
          result([[BLAppSDKManager sharedManager] p_toJsonString:param]);
      }];
  }  else {
    result(FlutterMethodNotImplemented);
  }
}

@end
